Commit 5123170b57 for wordpress.org
commit 5123170b57296c8f63ea2bbe1516c70c819b5b4e
Author: peterwilsoncc <peterwilsoncc@git.wordpress.org>
Date: Mon Oct 5 00:20:50 2026 +0000
Application Passwords: Clarify environment type required for non-SSL support.
Updates the inline documentation to indicate that the environment type must be set to `local` in order for Application Passwords to be supported over HTTP. Previously this was documented as requiring the environment be set to `development`.
Local environments are defined as environments that can not be reached via the internet whereas development environments are defined as being reachable via the internet. In the latter case an SSL connection is required in order to avoid sending plain text passwords across the internet.
Props sheldorofazeroth, annezazu, drtimofey, johnbillion, r1k0, sabernhardt, thakkarhardik.
Fixes #57388.
Built from https://develop.svn.wordpress.org/trunk@64091
git-svn-id: http://core.svn.wordpress.org/trunk@63250 1a063a9b-81f0-0310-95a4-ce76da25c4cd
diff --git a/wp-includes/version.php b/wp-includes/version.php
index a80a5f24a0..629d0462a4 100644
--- a/wp-includes/version.php
+++ b/wp-includes/version.php
@@ -16,7 +16,7 @@
*
* @global string $wp_version
*/
-$wp_version = '7.2-alpha-64090';
+$wp_version = '7.2-alpha-64091';
/**
* Holds the WordPress DB revision, increments when changes are made to the WordPress DB schema.
diff --git a/wp-admin/user-edit.php b/wp-admin/user-edit.php
index 9a31f13e58..f76cbd2bce 100644
--- a/wp-admin/user-edit.php
+++ b/wp-admin/user-edit.php
@@ -890,9 +890,10 @@ switch ( $action ) {
<p>
<?php
printf(
- /* translators: %s: Documentation URL. */
- __( 'If this is a development website, you can <a href="%s">set the environment type accordingly</a> to enable application passwords.' ),
- __( 'https://developer.wordpress.org/apis/wp-config-php/#wp-environment-type' )
+ /* translators: 1: Documentation URL, 2: local */
+ __( 'If this is a local website, you can <a href="%1$s">set the environment type</a> as %2$s to enable application passwords.' ),
+ __( 'https://developer.wordpress.org/apis/wp-config-php/#wp-environment-type' ),
+ '<code>local</code>'
);
?>
</p>